#[repr(transparent)]pub struct Cpu0nstckcal(pub u32);Expand description
Non-Secure CPU0 System Tick Calibration
Tuple Fields
0: u32Implementations
Sourceimpl Cpu0nstckcal
impl Cpu0nstckcal
Sourcepub const fn tenms(&self) -> u32
pub const fn tenms(&self) -> u32
Reload value for 10 ms (100 Hz) timing, subject to system clock skew errors. If the value reads as zero, the calibration value is not known.
Sourcepub const fn set_tenms(&mut self, val: u32)
pub const fn set_tenms(&mut self, val: u32)
Reload value for 10 ms (100 Hz) timing, subject to system clock skew errors. If the value reads as zero, the calibration value is not known.
Sourcepub const fn skew(&self) -> Cpu0nstckcalSkew
pub const fn skew(&self) -> Cpu0nstckcalSkew
Indicates whether the TENMS value is exact.
Sourcepub const fn set_skew(&mut self, val: Cpu0nstckcalSkew)
pub const fn set_skew(&mut self, val: Cpu0nstckcalSkew)
Indicates whether the TENMS value is exact.
Sourcepub const fn noref(&self) -> Cpu0nstckcalNoref
pub const fn noref(&self) -> Cpu0nstckcalNoref
Indicates whether the device provides a reference clock to the processor.
Sourcepub const fn set_noref(&mut self, val: Cpu0nstckcalNoref)
pub const fn set_noref(&mut self, val: Cpu0nstckcalNoref)
Indicates whether the device provides a reference clock to the processor.