nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

Cpu1stckcal

Struct Cpu1stckcal 

#[repr(transparent)]
pub struct Cpu1stckcal(pub u32);
System tick calibration for CPU1

Tuple Fields

0: u32

Implementations

Source

impl Cpu1stckcal

pub const fn tenms(&self) -> u32

Reload value for 10 ms (100 Hz) timing, subject to system clock skew errors. If the value reads as zero, the calibration value is not known.

pub const fn set_tenms(&mut self, val: u32)

Reload value for 10 ms (100 Hz) timing, subject to system clock skew errors. If the value reads as zero, the calibration value is not known.

pub const fn skew(&self) -> Cpu1stckcalSkew

Indicates whether the TENMS value is exact.

pub const fn set_skew(&mut self, val: Cpu1stckcalSkew)

Indicates whether the TENMS value is exact.

pub const fn noref(&self) -> Cpu1stckcalNoref

Indicates whether the device provides a reference clock to the processor.

pub const fn set_noref(&mut self, val: Cpu1stckcalNoref)

Indicates whether the device provides a reference clock to the processor.