#[repr(transparent)]pub struct ElsAsBootLog0(pub u32);Expand description
Boot state captured during boot: Main ROM log
Tuple Fields
0: u32Implementations
Sourceimpl ElsAsBootLog0
impl ElsAsBootLog0
Sourcepub const fn boot_image(&self) -> BootImage
pub const fn boot_image(&self) -> BootImage
Boot image source used during this boot.
Sourcepub const fn set_boot_image(&mut self, val: BootImage)
pub const fn set_boot_image(&mut self, val: BootImage)
Boot image source used during this boot.
Sourcepub const fn set_cmac(&mut self, val: bool)
pub const fn set_cmac(&mut self, val: bool)
CMAC verify is used instead of ECDSA verify on this boot.
Sourcepub const fn set_off_chip(&mut self, val: bool)
pub const fn set_off_chip(&mut self, val: bool)
Off-chip Prince is enabled during boot.
Sourcepub const fn set_on_chip(&mut self, val: bool)
pub const fn set_on_chip(&mut self, val: bool)
On-chip Prince is enabled during boot.
Sourcepub const fn cdi_csr(&self) -> bool
pub const fn cdi_csr(&self) -> bool
CDI based device keys are derived for CSR harvesting on this boot.
Sourcepub const fn set_cdi_csr(&mut self, val: bool)
pub const fn set_cdi_csr(&mut self, val: bool)
CDI based device keys are derived for CSR harvesting on this boot.
Sourcepub const fn set_cdi_dice(&mut self, val: bool)
pub const fn set_cdi_dice(&mut self, val: bool)
CDI per DICE specification is computed on this boot.
Sourcepub const fn set_trustzone(&mut self, val: bool)
pub const fn set_trustzone(&mut self, val: bool)
TrustZone preset data is loaded during this boot.
Sourcepub const fn debug_auth(&self) -> bool
pub const fn debug_auth(&self) -> bool
Debug authentication done in this session prior to boot.
Sourcepub const fn set_debug_auth(&mut self, val: bool)
pub const fn set_debug_auth(&mut self, val: bool)
Debug authentication done in this session prior to boot.
Sourcepub const fn set_itrc(&mut self, val: bool)
pub const fn set_itrc(&mut self, val: bool)
ITRC zeroize event is handled in this session of boot.
Sourcepub const fn set_dig_gdet(&mut self, val: bool)
pub const fn set_dig_gdet(&mut self, val: bool)
Digital glitch detector is enabled during boot.
Sourcepub const fn set_ana_gdet(&mut self, val: bool)
pub const fn set_ana_gdet(&mut self, val: bool)
Analog glitch detector is enabled during boot.
Sourcepub const fn set_deep_pd(&mut self, val: bool)
pub const fn set_deep_pd(&mut self, val: bool)
Boot from deep-power down state.
Sourcepub const fn low_power(&self) -> u8
pub const fn low_power(&self) -> u8
Last low-power mode value. ROM copies SPC_LP_MODE field from SPC->SC[7:4].
Sourcepub const fn set_low_power(&mut self, val: u8)
pub const fn set_low_power(&mut self, val: u8)
Last low-power mode value. ROM copies SPC_LP_MODE field from SPC->SC[7:4].