#[repr(transparent)]pub struct ElsAsCfg0(pub u32);Expand description
ELS AS Configuration
Tuple Fields
0: u32Implementations
Sourceimpl ElsAsCfg0
impl ElsAsCfg0
Sourcepub const fn cfg_lc_state(&self) -> u8
pub const fn cfg_lc_state(&self) -> u8
LC state configuration bit
Sourcepub const fn set_cfg_lc_state(&mut self, val: u8)
pub const fn set_cfg_lc_state(&mut self, val: u8)
LC state configuration bit
Sourcepub const fn cfg_lvd_core_reset_enabled(&self) -> bool
pub const fn cfg_lvd_core_reset_enabled(&self) -> bool
When SPC CORE LVD analog detector are turned on, and CORE LVD reset are enabled, this bit indicates state 1.
Sourcepub const fn set_cfg_lvd_core_reset_enabled(&mut self, val: bool)
pub const fn set_cfg_lvd_core_reset_enabled(&mut self, val: bool)
When SPC CORE LVD analog detector are turned on, and CORE LVD reset are enabled, this bit indicates state 1.
Sourcepub const fn cfg_lvd_core_irq_enabled(&self) -> bool
pub const fn cfg_lvd_core_irq_enabled(&self) -> bool
When SPC CORE LVD analog detector are turned on, and CORE LVD IRQ are enabled, this bit indicates state 1.
Sourcepub const fn set_cfg_lvd_core_irq_enabled(&mut self, val: bool)
pub const fn set_cfg_lvd_core_irq_enabled(&mut self, val: bool)
When SPC CORE LVD analog detector are turned on, and CORE LVD IRQ are enabled, this bit indicates state 1.
Sourcepub const fn cfg_wdt0_enabled(&self) -> bool
pub const fn cfg_wdt0_enabled(&self) -> bool
When WatchDog Timer 0 is activated, this bit indicates state 1
Sourcepub const fn set_cfg_wdt0_enabled(&mut self, val: bool)
pub const fn set_cfg_wdt0_enabled(&mut self, val: bool)
When WatchDog Timer 0 is activated, this bit indicates state 1
Sourcepub const fn cfg_cwdt0_enabled(&self) -> bool
pub const fn cfg_cwdt0_enabled(&self) -> bool
When Code WatchDog Timer 0 is activated, this bit indicates state 1
Sourcepub const fn set_cfg_cwdt0_enabled(&mut self, val: bool)
pub const fn set_cfg_cwdt0_enabled(&mut self, val: bool)
When Code WatchDog Timer 0 is activated, this bit indicates state 1
Sourcepub const fn cfg_els_gdet_enabled(&self) -> bool
pub const fn cfg_els_gdet_enabled(&self) -> bool
When either GDET is enabled, this bit indicates state 1.
Sourcepub const fn set_cfg_els_gdet_enabled(&mut self, val: bool)
pub const fn set_cfg_els_gdet_enabled(&mut self, val: bool)
When either GDET is enabled, this bit indicates state 1.
Sourcepub const fn cfg_ana_gdet_reset_enabled(&self) -> bool
pub const fn cfg_ana_gdet_reset_enabled(&self) -> bool
When SPC analog glitch detect reset is enabled, this bit indicates state 1
Sourcepub const fn set_cfg_ana_gdet_reset_enabled(&mut self, val: bool)
pub const fn set_cfg_ana_gdet_reset_enabled(&mut self, val: bool)
When SPC analog glitch detect reset is enabled, this bit indicates state 1
Sourcepub const fn cfg_ana_gdet_irq_enabled(&self) -> bool
pub const fn cfg_ana_gdet_irq_enabled(&self) -> bool
When SPC analog glitch detect IRQ is enabled, this bit indicates state 1
Sourcepub const fn set_cfg_ana_gdet_irq_enabled(&mut self, val: bool)
pub const fn set_cfg_ana_gdet_irq_enabled(&mut self, val: bool)
When SPC analog glitch detect IRQ is enabled, this bit indicates state 1
Sourcepub const fn cfg_tamper_det_enabled(&self) -> bool
pub const fn cfg_tamper_det_enabled(&self) -> bool
When tamper detector is enabled in TDET, this bit indicates state 1.
Sourcepub const fn set_cfg_tamper_det_enabled(&mut self, val: bool)
pub const fn set_cfg_tamper_det_enabled(&mut self, val: bool)
When tamper detector is enabled in TDET, this bit indicates state 1.
Sourcepub const fn cfg_lvd_vsys_reset_enabled(&self) -> bool
pub const fn cfg_lvd_vsys_reset_enabled(&self) -> bool
When SPC VSYS LVD analog detector are turned on and VSYS LVD reset are enabled, this bit indicates state 1.
Sourcepub const fn set_cfg_lvd_vsys_reset_enabled(&mut self, val: bool)
pub const fn set_cfg_lvd_vsys_reset_enabled(&mut self, val: bool)
When SPC VSYS LVD analog detector are turned on and VSYS LVD reset are enabled, this bit indicates state 1.
Sourcepub const fn cfg_lvd_vddio_reset_enabled(&self) -> bool
pub const fn cfg_lvd_vddio_reset_enabled(&self) -> bool
When SPC VDDIO LVD analog detector are turned on and VDDIO LVD reset are enabled, this bit indicates state 1.
Sourcepub const fn set_cfg_lvd_vddio_reset_enabled(&mut self, val: bool)
pub const fn set_cfg_lvd_vddio_reset_enabled(&mut self, val: bool)
When SPC VDDIO LVD analog detector are turned on and VDDIO LVD reset are enabled, this bit indicates state 1.
Sourcepub const fn cfg_lvd_vsys_irq_enabled(&self) -> bool
pub const fn cfg_lvd_vsys_irq_enabled(&self) -> bool
When SPC VSYS LVD analog detector are turned on and VSYS LVD irq are enabled, this bit indicates state 1.
Sourcepub const fn set_cfg_lvd_vsys_irq_enabled(&mut self, val: bool)
pub const fn set_cfg_lvd_vsys_irq_enabled(&mut self, val: bool)
When SPC VSYS LVD analog detector are turned on and VSYS LVD irq are enabled, this bit indicates state 1.
Sourcepub const fn cfg_lvd_vddio_irq_enabled(&self) -> bool
pub const fn cfg_lvd_vddio_irq_enabled(&self) -> bool
When SPC VDDIO LVD analog detector are turned on and VDDIO LVD irq are enabled, this bit indicates state 1.
Sourcepub const fn set_cfg_lvd_vddio_irq_enabled(&mut self, val: bool)
pub const fn set_cfg_lvd_vddio_irq_enabled(&mut self, val: bool)
When SPC VDDIO LVD analog detector are turned on and VDDIO LVD irq are enabled, this bit indicates state 1.
Sourcepub const fn cfg_wdt1_enabled(&self) -> bool
pub const fn cfg_wdt1_enabled(&self) -> bool
When WatchDog Timer 1 is activated, this bit indicates state 1.
Sourcepub const fn set_cfg_wdt1_enabled(&mut self, val: bool)
pub const fn set_cfg_wdt1_enabled(&mut self, val: bool)
When WatchDog Timer 1 is activated, this bit indicates state 1.
Sourcepub const fn cfg_cwdt1_enabled(&self) -> bool
pub const fn cfg_cwdt1_enabled(&self) -> bool
When Code WatchDog Timer 1 is activated, this bit indicates state 1.
Sourcepub const fn set_cfg_cwdt1_enabled(&mut self, val: bool)
pub const fn set_cfg_cwdt1_enabled(&mut self, val: bool)
When Code WatchDog Timer 1 is activated, this bit indicates state 1.
Sourcepub const fn cfg_temptamper_det_enabled(&self) -> bool
pub const fn cfg_temptamper_det_enabled(&self) -> bool
When temperature tamper detector is enabled in VBAT, this bit indicates state 1.
Sourcepub const fn set_cfg_temptamper_det_enabled(&mut self, val: bool)
pub const fn set_cfg_temptamper_det_enabled(&mut self, val: bool)
When temperature tamper detector is enabled in VBAT, this bit indicates state 1.
Sourcepub const fn cfg_voltamper_det_enabled(&self) -> bool
pub const fn cfg_voltamper_det_enabled(&self) -> bool
When voltage tamper detector is enabled in VBAT, this bit indicates state 1.
Sourcepub const fn set_cfg_voltamper_det_enabled(&mut self, val: bool)
pub const fn set_cfg_voltamper_det_enabled(&mut self, val: bool)
When voltage tamper detector is enabled in VBAT, this bit indicates state 1.
Sourcepub const fn cfg_lhttamper_det_enabled(&self) -> bool
pub const fn cfg_lhttamper_det_enabled(&self) -> bool
When light tamper detector is enabled in VBAT, this bit indicates state 1.
Sourcepub const fn set_cfg_lhttamper_det_enabled(&mut self, val: bool)
pub const fn set_cfg_lhttamper_det_enabled(&mut self, val: bool)
When light tamper detector is enabled in VBAT, this bit indicates state 1.
Sourcepub const fn cfg_clktamper_det_enabled(&self) -> bool
pub const fn cfg_clktamper_det_enabled(&self) -> bool
When clk tamper detector is enabled in VBAT, this bit indicates state 1.
Sourcepub const fn set_cfg_clktamper_det_enabled(&mut self, val: bool)
pub const fn set_cfg_clktamper_det_enabled(&mut self, val: bool)
When clk tamper detector is enabled in VBAT, this bit indicates state 1.
Sourcepub const fn cfg_qk_disable_enroll(&self) -> bool
pub const fn cfg_qk_disable_enroll(&self) -> bool
When QK PUF “qk_disable_enroll” input is driven 1, this bit indicates state 1
Sourcepub const fn set_cfg_qk_disable_enroll(&mut self, val: bool)
pub const fn set_cfg_qk_disable_enroll(&mut self, val: bool)
When QK PUF “qk_disable_enroll” input is driven 1, this bit indicates state 1
Sourcepub const fn cfg_qk_disable_wrap(&self) -> bool
pub const fn cfg_qk_disable_wrap(&self) -> bool
When QK PUF “qk_disable_wrap” input is driven 1, this bit indicates state 1
Sourcepub const fn set_cfg_qk_disable_wrap(&mut self, val: bool)
pub const fn set_cfg_qk_disable_wrap(&mut self, val: bool)
When QK PUF “qk_disable_wrap” input is driven 1, this bit indicates state 1