#[repr(transparent)]pub struct ElsAssetProt(pub u32);Expand description
ELS Asset Protection Register
Tuple Fields
0: u32Implementations
Sourceimpl ElsAssetProt
impl ElsAssetProt
Sourcepub const fn asset_protection(&self) -> AssetProtection
pub const fn asset_protection(&self) -> AssetProtection
ELS asset protection. This field controls the asset protection port to the ELS module. Refer to the ELS chapter in the SRM for more details.
Sourcepub const fn set_asset_protection(&mut self, val: AssetProtection)
pub const fn set_asset_protection(&mut self, val: AssetProtection)
ELS asset protection. This field controls the asset protection port to the ELS module. Refer to the ELS chapter in the SRM for more details.