nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

KeyRetainCtrl

Struct KeyRetainCtrl 

#[repr(transparent)]
pub struct KeyRetainCtrl(pub u32);
Key Retain Control

Tuple Fields

0: u32

Implementations

Source

impl KeyRetainCtrl

pub const fn key_retain_valid(&self) -> bool

Indicates if the PUF key has been retained in the VBAT domain and has not been reset or otherwise invalidated by software.

pub const fn set_key_retain_valid(&mut self, val: bool)

Indicates if the PUF key has been retained in the VBAT domain and has not been reset or otherwise invalidated by software.

pub const fn key_retain_done(&self) -> bool

Indicates the successful completion of the key_save or key_load routine. Once set, to clear the key_retain_done flag, both key_save and key_load should be cleared by software.

pub const fn set_key_retain_done(&mut self, val: bool)

Indicates the successful completion of the key_save or key_load routine. Once set, to clear the key_retain_done flag, both key_save and key_load should be cleared by software.

pub const fn key_save(&self) -> bool

Do not set both KEY_SAVE and KEY_LOAD at the same time

pub const fn set_key_save(&mut self, val: bool)

Do not set both KEY_SAVE and KEY_LOAD at the same time

pub const fn key_load(&self) -> bool

Do not set both KEY_SAVE and KEY_LOAD at the same time

pub const fn set_key_load(&mut self, val: bool)

Do not set both KEY_SAVE and KEY_LOAD at the same time