nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

Romcr

Struct Romcr 

#[repr(transparent)]
pub struct Romcr(pub u32);
ROM Wait State

Tuple Fields

0: u32

Implementations

Source

impl Romcr

pub const fn rom_wait(&self) -> bool

ROM waiting Arm core and other masters for one cycle

pub const fn set_rom_wait(&mut self, val: bool)

ROM waiting Arm core and other masters for one cycle