#[repr(transparent)]pub struct KeyRetainCtrl(pub u32);Expand description
Key Retain Control
Tuple Fields
0: u32Implementations
Sourceimpl KeyRetainCtrl
impl KeyRetainCtrl
Sourcepub const fn key_retain_valid(&self) -> bool
pub const fn key_retain_valid(&self) -> bool
Indicates if the PUF key has been retained in the VBAT domain and has not been reset or otherwise invalidated by software.
Sourcepub const fn set_key_retain_valid(&mut self, val: bool)
pub const fn set_key_retain_valid(&mut self, val: bool)
Indicates if the PUF key has been retained in the VBAT domain and has not been reset or otherwise invalidated by software.
Sourcepub const fn key_retain_done(&self) -> bool
pub const fn key_retain_done(&self) -> bool
Indicates the successful completion of the key_save or key_load routine. Once set, to clear the key_retain_done flag, both key_save and key_load should be cleared by software.
Sourcepub const fn set_key_retain_done(&mut self, val: bool)
pub const fn set_key_retain_done(&mut self, val: bool)
Indicates the successful completion of the key_save or key_load routine. Once set, to clear the key_retain_done flag, both key_save and key_load should be cleared by software.
Sourcepub const fn set_key_save(&mut self, val: bool)
pub const fn set_key_save(&mut self, val: bool)
Do not set both KEY_SAVE and KEY_LOAD at the same time
Sourcepub const fn set_key_load(&mut self, val: bool)
pub const fn set_key_load(&mut self, val: bool)
Do not set both KEY_SAVE and KEY_LOAD at the same time